@@ -392,7 +392,7 @@ gnc_lot_viewer_fill (GNCLotViewer *lv)
         }
         else
         {
-            gtk_list_store_set(store, &iter, LOT_COL_CLOSE, 0, -1);
+            gtk_list_store_set(store, &iter, LOT_COL_CLOSE, 0LL, -1);
         }
 
         /* Title */
